@@ -2,19 +2,22 @@
 # -*- coding: utf-8 -*-
 
 import json
-import urllib
+import urllib2
 from hobonickels_utils import get_addr
 from hobonickels_utils import exchange
 from hobonickels_utils import gen_eckey
 from hobonickels_utils import blockexplorer
 
 __title__   = 'hobonickels'
-__version__ = '1.0.1'
+__version__ = '1.0.2'
 __author__  = '@c0ding'
 __repo__    = 'https://github.com/c0ding/hobonickels-api'
 __license__ = 'Apache v2.0 License'
 
 
+BROWSER_HEADER = {'User-Agent' : 'Mozilla/5.0 (X11; Linux i586; rv:31.0) Gecko/20100101 Firefox/36.0'}
+
+
 def about():
 	"""Returns some information about the hobonickels module."""
 
@@ -24,7 +27,7 @@ def about():
 def difficulty():
 	"""Returns the current network difficulty."""
 
-	d = urllib.urlopen(blockexplorer('getdifficulty'))
+	d = urllib2.urlopen(blockexplorer('getdifficulty'))
 	return float(d.read())
 
 
@@ -33,7 +36,7 @@ def hashrate():
 
 	c = block_count()
 	blocks = "%.0f" %c
-	d = urllib.urlopen(blockexplorer('nethash') + '/' + str(blocks))
+	d = urllib2.urlopen(blockexplorer('nethash') + '/' + str(blocks))
 	last_line = d.readlines()[-1]
 	e = last_line.split(',')
 	return e[-1]
@@ -44,14 +47,14 @@ def block_count():
 	   Equivalent to Bitcoin's getblockcount.
 	"""
 
-	d = urllib.urlopen(blockexplorer('getblockcount'))
+	d = urllib2.urlopen(blockexplorer('getblockcount'))
 	return float(d.read())
 
 
 def total_coins():
 	"""Returns the number of Hobonickels mined."""
 	
-	d = urllib.urlopen(blockexplorer('totalbc'))
+	d = urllib2.urlopen(blockexplorer('totalbc'))
 	return float(d.read())
 
 
@@ -60,7 +63,7 @@ def addressbalance(PARAMETER):
 	   [PARAMETER] is required and should be a HBN address.
 	"""
 	
-	d = urllib.urlopen(blockexplorer('addressbalance') + '/' + str(PARAMETER))
+	d = urllib2.urlopen(blockexplorer('addressbalance') + '/' + str(PARAMETER))
 	return float(d.read())
 
 
@@ -69,7 +72,7 @@ def addresstohash(PARAMETER):
 	   [PARAMETER] is required and should be a HBN address.
 	"""
 	
-	d = urllib.urlopen(blockexplorer('addresstohash') + '/' + str(PARAMETER))
+	d = urllib2.urlopen(blockexplorer('addresstohash') + '/' + str(PARAMETER))
 	return d.read()
 
 
@@ -79,7 +82,7 @@ def checkaddress(PARAMETER):
 	   [PARAMETER] is required and can be any crypto address.
 	"""
 
-	d = urllib.urlopen(blockexplorer('checkaddress') + '/' + str(PARAMETER))
+	d = urllib2.urlopen(blockexplorer('checkaddress') + '/' + str(PARAMETER))
 	return d.read()
 
 
@@ -88,7 +91,7 @@ def decode_address(PARAMETER):
 	    [PARAMETER] is required and can be any crypto address.
 	 """
 
-	 d = urllib.urlopen(blockexplorer('decode_address') + '/' + str(PARAMETER))
+	 d = urllib2.urlopen(blockexplorer('decode_address') + '/' + str(PARAMETER))
 	 return d.read()
 
 
@@ -97,7 +100,7 @@ def getreceivedbyaddress(PARAMETER):
 	   [PARAMETER] is required and should be a HBN address.
 	"""
 
-	d = urllib.urlopen(blockexplorer('getreceivedbyaddress') + '/' + str(PARAMETER))
+	d = urllib2.urlopen(blockexplorer('getreceivedbyaddress') + '/' + str(PARAMETER))
 	return d.read()
 
 
@@ -106,7 +109,7 @@ def getsentbyaddress(PARAMETER):
 	   [PARAMETER] is required and should be a HBN address.
 	"""
 
-	d = urllib.urlopen(blockexplorer('getsentbyaddress') + '/' + str(PARAMETER))
+	d = urllib2.urlopen(blockexplorer('getsentbyaddress') + '/' + str(PARAMETER))
 	return d.read()
 
 
@@ -115,7 +118,7 @@ def hashpubkey(PARAMETER):
 	   [PARAMETER] is required and should be a PUBKEY.
 	"""
 
-	d = urllib.urlopen(blockexplorer('hashpubkey') + '/' + str(PARAMETER))
+	d = urllib2.urlopen(blockexplorer('hashpubkey') + '/' + str(PARAMETER))
 	return d.read()
 
 
@@ -124,7 +127,7 @@ def hashtoaddress(PARAMETER):
 	   [PARAMETER] is required and should be an address hash.
 	"""
 
-	d = urllib.urlopen(blockexplorer('hashtoaddress') + '/' + str(PARAMETER))
+	d = urllib2.urlopen(blockexplorer('hashtoaddress') + '/' + str(PARAMETER))
 	return d.read()
 
 
@@ -133,7 +136,7 @@ def translate_address(PARAMETER):
 	   [PARAMETER] is required and can be any crypto address.
 	"""
 
-	d = urllib.urlopen(blockexplorer('translate_address') + '/' + str(PARAMETER))
+	d = urllib2.urlopen(blockexplorer('translate_address') + '/' + str(PARAMETER))
 	return d.read()
 	
 
@@ -148,6 +151,8 @@ def generate_address():
 
 def to_btc():
 	"""Returns array with trading pair object."""
-	
-	d = urllib.urlopen(exchange('hbn_btc'))
+
+
+	c = urllib2.Request(exchange('hbn_btc'), headers = BROWSER_HEADER)
+	d = urllib2.urlopen(c)
 	return json.loads(d.read())
