@@ -7,6 +7,12 @@ import ctypes
 import hashlib
 import ctypes.util
 
+__title__   = 'hobonickels'
+__version__ = '1.0.2'
+__author__  = '@c0ding'
+__repo__    = 'https://github.com/c0ding/hobonickels-api'
+__license__ = 'Apache v2.0 License'
+
 """This part of the code is where the magic happens.
    # Joric/bitcoin-dev, june 2012, public domain
    # modified by c0ding, 2014
@@ -187,7 +193,8 @@ def reencode(pkey,version=0):
 
 
 HBN_BLOCKEXPLORER = 'http://hbn.blockx.info/abe/chain/HoboNickels/q/'
-CRYPTOCOIN_API = 'http://www.cryptocoincharts.info/v2/api/tradingPair/'
+CRYPTOCOIN_API = 'http://api.cryptocoincharts.info/tradingPair/'
+
 
 def blockexplorer(*suffix):
 	"""Returns the entrypoint URL for the Hobonickels block API.
@@ -198,7 +205,7 @@ def blockexplorer(*suffix):
 	return HBN_BLOCKEXPLORER + '/'.join(suffix)
 
 def exchange(*suffix):
-	"""Returns the entrypoint URL for the Worldcoin price API.
+	"""Returns the entrypoint URL for the Hobonickels price API.
 	   All data provided by CryptoCoin.
 	   http://www.cryptocoincharts.info
 	"""
